Problem Toolbox

Tools to work with multiple problem formats: DSA, Hackerrank, CMS, repl...


# Description
    
Main functions

## DSA problem tools

## Hackerrank problem tools

# Installation
 
## Normal installation

```bash
pip install ptoolbox
```

## Development installation

```bash
git clone https://gitlab.com/thucnguyen/ptoolbox.git
cd ptoolbox
pip install --editable .
```

# Usage
## DSA problem tools
```bash
ptoolbox dsa --help
```

## Hackerrank problem tools
```bash
ptoolbox hackerrank --help
```